@@ -263,6 +263,7 @@ class trainer:
         outputdir: str = "outputs",
         early_stopping_patience_epochs: int = 0,  # 0 to disable early stopping feature
         test_split=0.1,
+        tpu_cores = None,
     ):
         """
         trains T5 model on custom dataset
@@ -323,6 +324,7 @@ class trainer:
             max_epochs=max_epochs,
             gpus=gpus,
             progress_bar_refresh_rate=5,
+            tpu_cores=tpu_cores
         )
 
         trainer.fit(self.T5Model, self.data_module)
